@@ -18,6 +18,7 @@ import tempfile
 import time
 from collections import namedtuple
 from datetime import datetime, timedelta
+from sys import version_info
 
 import requests  # pylint: disable=import-error
 from pytz import timezone  # pylint: disable=import-error
@@ -26,7 +27,16 @@ from .extract import extract_dmg, extract_tar, extract_zip
 from .path import onerror
 from .path import rmtree as junction_rmtree
 
+if version_info[:2] < (3, 8):
+    # pylint: disable=import-error
+    from importlib_metadata import PackageNotFoundError, version
+else:
+    # pylint: disable=import-error
+    from importlib.metadata import PackageNotFoundError, version
+
+
 __all__ = (
+    "__version__",
     "BuildFlags",
     "BuildTask",
     "Fetcher",
@@ -39,6 +49,11 @@ __all__ = (
     "si",
 )
 
+try:
+    __version__ = version("fuzzfetch")
+except PackageNotFoundError:
+    # package is not installed
+    __version__ = None
 
 LOG = logging.getLogger("fuzzfetch")
 
@@ -442,7 +457,9 @@ class FetcherArgs(object):
         """
         super().__init__()
         if not hasattr(self, "parser"):
-            self.parser = argparse.ArgumentParser(conflict_handler="resolve")
+            self.parser = argparse.ArgumentParser(
+                conflict_handler="resolve", prog="fuzzfetch"
+            )
 
         self.parser.set_defaults(
             target="firefox", build="latest", tests=None
@@ -705,7 +722,7 @@ class Fetcher(object):
                 # If branch wasn't set, try and retrieve it from the build string
                 if self._branch is None:
                     branch = re.search(
-                        r"\.(try|mozilla-(?P<branch>[a-z]+[0-9]*))\.", build
+                        r"\.(autoland|try|mozilla-(?P<branch>[a-z]+[0-9]*))\.", build
                     )
                     self._branch = branch.group("branch") if branch is not None else "?"
                     if self._branch is None:
@@ -871,8 +888,8 @@ class Fetcher(object):
             options = build.split(self.moz_info["platform_guess"], 1)[1]
         else:
             options = self._flags.build_string()
-        if self._branch == "try":
-            branch = "try"
+        if self._branch in {"autoland", "try"}:
+            branch = self._branch
         else:
             branch = "m-%s" % (self._branch[0],)
         self._auto_name = "%s%s-%s%s" % (
@@ -1073,7 +1090,7 @@ class Fetcher(object):
                 # fuzzing debug builds no longer have crashreporter-symbols.zip
                 # (bug 1649062)
                 # we want to maintain support for older builds for now
-                if not (self._flags.debug and self._flags.fuzzing):
+                if not self._flags.fuzzing:
                     raise
 
         self._write_fuzzmanagerconf(path)
@@ -1222,15 +1239,21 @@ class Fetcher(object):
                                          for extract_build.
         """
         parser = FetcherArgs()
+        parser.parser.add_argument(
+            "-V", "--version", action="store_true", help="print version and exit"
+        )
         args = parser.parse_args(args)
+        if args.version:
+            print("fuzzfetch %s" % (__version__,))
+            raise SystemExit(0)
 
         # do this default manually so we can error if combined with --build namespace
         # parser.set_defaults(branch='central')
-        if not parser.is_build_ns(args.build) and args.branch is None:
-            args.branch = "central"
-
-        if args.branch.startswith("esr"):
-            args.branch = Fetcher.resolve_esr(args.branch)
+        if not parser.is_build_ns(args.build):
+            if args.branch is None:
+                args.branch = "central"
+            elif args.branch.startswith("esr"):
+                args.branch = Fetcher.resolve_esr(args.branch)
 
         flags = BuildFlags(
             args.asan, args.tsan, args.debug, args.fuzzing, args.coverage, args.valgrind
